@@ -92,6 +92,9 @@ public:
     virtual void setChannelVolumes(const QVector<qint64> &channelVolumes) = 0;
     Q_INVOKABLE virtual void setChannelVolume(int channel, qint64 volume) = 0;
 
+    virtual quint32 sourceIndex() const {return -1;};
+    virtual quint32 streamIndex() const {return -1;};
+
 Q_SIGNALS:
     void volumeChanged();
     void mutedChanged();
@@ -100,6 +103,7 @@ Q_SIGNALS:
     void channelsChanged();
     void rawChannelsChanged();
     void channelVolumesChanged();
+    void sourceIndexChanged();
 
 protected:
     pa_cvolume cvolume() const;
